# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: autopilot.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x61utopilot.proto\x12\x1amagothy.protobuf.autopilot\x1a\x1fgoogle/protobuf/timestamp.proto\"(\n\x05\x45rror\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\"7\n\x08Position\x12\x14\n\x0clatitude_deg\x18\x01 \x01(\x01\x12\x15\n\rlongitude_deg\x18\x02 \x01(\x01\":\n\x0b\x41ngularRate\x12\r\n\x05x_dps\x18\x01 \x01(\x01\x12\r\n\x05y_dps\x18\x02 \x01(\x01\x12\r\n\x05z_dps\x18\x03 \x01(\x01\">\n\x0c\x41\x63\x63\x65leration\x12\x0e\n\x06x_mps2\x18\x01 \x01(\x01\x12\x0e\n\x06y_mps2\x18\x02 \x01(\x01\x12\x0e\n\x06z_mps2\x18\x03 \x01(\x01\"B\n\rMagneticField\x12\x0f\n\x07x_gauss\x18\x01 \x01(\x01\x12\x0f\n\x07y_gauss\x18\x02 \x01(\x01\x12\x0f\n\x07z_gauss\x18\x03 \x01(\x01\"A\n\x05\x45uler\x12\x10\n\x08roll_deg\x18\x01 \x01(\x01\x12\x11\n\tpitch_deg\x18\x02 \x01(\x01\x12\x13\n\x0bheading_deg\x18\x03 \x01(\x01\";\n\x0c\x42odyVelocity\x12\r\n\x05x_mps\x18\x01 \x01(\x01\x12\r\n\x05y_mps\x18\x02 \x01(\x01\x12\r\n\x05z_mps\x18\x03 \x01(\x01\"I\n\x10InertialVelocity\x12\x11\n\tnorth_mps\x18\x01 \x01(\x01\x12\x10\n\x08\x65\x61st_mps\x18\x02 \x01(\x01\x12\x10\n\x08\x64own_mps\x18\x03 \x01(\x01\"8\n\x0cWaterCurrent\x12\x11\n\tspeed_mps\x18\x01 \x01(\x01\x12\x15\n\rdirection_deg\x18\x02 \x01(\x01\"R\n\tFuelGauge\x12\x11\n\tvoltage_V\x18\x01 \x01(\x01\x12\x11\n\tcurrent_A\x18\x02 \x01(\x01\x12\x1f\n\x17state_of_charge_percent\x18\x03 \x01(\x01\"\xad\x17\n\x0bVehicleData\x12;\n\x08position\x18\x01 \x01(\x0b\x32$.magothy.protobuf.autopilot.PositionH\x00\x88\x01\x01\x12K\n\x0fposition_source\x18\x02 \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12\x1f\n\x17position_ttag_ns_steady\x18\x03 \x01(\x04\x12@\n\x10position_error_m\x18( \x01(\x0b\x32!.magothy.protobuf.autopilot.ErrorH\x01\x88\x01\x01\x12Q\n\x15position_error_source\x18) \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12%\n\x1dposition_error_ttag_ns_steady\x18* \x01(\x04\x12\x38\n\x08\x61ttitude\x18\x04 \x01(\x0b\x32!.magothy.protobuf.autopilot.EulerH\x02\x88\x01\x01\x12K\n\x0f\x61ttitude_source\x18\x05 \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12\x1f\n\x17\x61ttitude_ttag_ns_steady\x18\x06 \x01(\x04\x12\x42\n\x12\x61ttitude_error_deg\x18+ \x01(\x0b\x32!.magothy.protobuf.autopilot.ErrorH\x03\x88\x01\x01\x12Q\n\x15\x61ttitude_error_source\x18, \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12%\n\x1d\x61ttitude_error_ttag_ns_steady\x18- \x01(\x04\x12\x42\n\x0c\x61ngular_rate\x18\x07 \x01(\x0b\x32\'.magothy.protobuf.autopilot.AngularRateH\x04\x88\x01\x01\x12O\n\x13\x61ngular_rate_source\x18\x08 \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12#\n\x1b\x61ngular_rate_ttag_ns_steady\x18\t \x01(\x04\x12\x43\n\x0c\x61\x63\x63\x65leration\x18\n \x01(\x0b\x32(.magothy.protobuf.autopilot.AccelerationH\x05\x88\x01\x01\x12O\n\x13\x61\x63\x63\x65leration_source\x18\x0b \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12#\n\x1b\x61\x63\x63\x65leration_ttag_ns_steady\x18\x0c \x01(\x04\x12\x46\n\x0emagnetic_field\x18\r \x01(\x0b\x32).magothy.protobuf.autopilot.MagneticFieldH\x06\x88\x01\x01\x12Q\n\x15magnetic_field_source\x18\x0e \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12%\n\x1dmagnetic_field_ttag_ns_steady\x18\x0f \x01(\x04\x12\x14\n\x07\x64\x65pth_m\x18\x10 \x01(\x01H\x07\x88\x01\x01\x12H\n\x0c\x64\x65pth_source\x18\x11 \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12\x1c\n\x14\x64\x65pth_ttag_ns_steady\x18\x12 \x01(\x04\x12\x17\n\naltitude_m\x18\x13 \x01(\x01H\x08\x88\x01\x01\x12K\n\x0f\x61ltitude_source\x18\x14 \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12\x1f\n\x17\x61ltitude_ttag_ns_steady\x18\x15 \x01(\x04\x12\x16\n\tspeed_mps\x18\x16 \x01(\x01H\t\x88\x01\x01\x12H\n\x0cspeed_source\x18\x17 \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12\x1c\n\x14speed_ttag_ns_steady\x18\x18 \x01(\x04\x12\x17\n\ncourse_deg\x18\x19 \x01(\x01H\n\x88\x01\x01\x12I\n\rcourse_source\x18\x1a \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12\x1d\n\x15\x63ourse_ttag_ns_steady\x18\x1b \x01(\x04\x12\x44\n\rbody_velocity\x18\x1c \x01(\x0b\x32(.magothy.protobuf.autopilot.BodyVelocityH\x0b\x88\x01\x01\x12P\n\x14\x62ody_velocity_source\x18\x1d \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12$\n\x1c\x62ody_velocity_ttag_ns_steady\x18\x1e \x01(\x04\x12\x44\n\rwater_current\x18\x1f \x01(\x0b\x32(.magothy.protobuf.autopilot.WaterCurrentH\x0c\x88\x01\x01\x12P\n\x14water_current_source\x18  \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12$\n\x1cwater_current_ttag_ns_steady\x18! \x01(\x04\x12%\n\x18water_relative_speed_mps\x18\" \x01(\x01H\r\x88\x01\x01\x12W\n\x1bwater_relative_speed_source\x18# \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12+\n#water_relative_speed_ttag_ns_steady\x18$ \x01(\x04\x12>\n\nfuel_gauge\x18% \x01(\x0b\x32%.magothy.protobuf.autopilot.FuelGaugeH\x0e\x88\x01\x01\x12M\n\x11\x66uel_gauge_source\x18& \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12!\n\x19\x66uel_gauge_ttag_ns_steady\x18\' \x01(\x04\"\xb3\x01\n\nDataSource\x12\r\n\tDS_NODATA\x10\x00\x12\n\n\x06\x44S_IMU\x10\x01\x12\x0b\n\x07\x44S_AHRS\x10\x02\x12\n\n\x06\x44S_GPS\x10\x03\x12\x0c\n\x08\x44S_DEPTH\x10\x04\x12\x0f\n\x0b\x44S_ALTITUDE\x10\x05\x12\x0c\n\x08\x44S_SPEED\x10\x06\x12\x11\n\rDS_ESTIMATION\x10\x07\x12\x12\n\x0e\x44S_COMPUTATION\x10\x08\x12\x11\n\rDS_SIMULATION\x10\t\x12\n\n\x06\x44S_INS\x10\nB\x0b\n\t_positionB\x13\n\x11_position_error_mB\x0b\n\t_attitudeB\x15\n\x13_attitude_error_degB\x0f\n\r_angular_rateB\x0f\n\r_accelerationB\x11\n\x0f_magnetic_fieldB\n\n\x08_depth_mB\r\n\x0b_altitude_mB\x0c\n\n_speed_mpsB\r\n\x0b_course_degB\x10\n\x0e_body_velocityB\x10\n\x0e_water_currentB\x1b\n\x19_water_relative_speed_mpsB\r\n\x0b_fuel_gauge\"\x98\x03\n\x06\x41hrsIf\x12\x42\n\x0c\x61ngular_rate\x18\x01 \x01(\x0b\x32\'.magothy.protobuf.autopilot.AngularRateH\x00\x88\x01\x01\x12\x43\n\x0c\x61\x63\x63\x65leration\x18\x02 \x01(\x0b\x32(.magothy.protobuf.autopilot.AccelerationH\x01\x88\x01\x01\x12@\n\x08magfield\x18\x03 \x01(\x0b\x32).magothy.protobuf.autopilot.MagneticFieldH\x02\x88\x01\x01\x12\x35\n\x05\x65uler\x18\x04 \x01(\x0b\x32!.magothy.protobuf.autopilot.EulerH\x03\x88\x01\x01\x12?\n\x0f\x65uler_error_deg\x18\x07 \x01(\x0b\x32!.magothy.protobuf.autopilot.ErrorH\x04\x88\x01\x01\x42\x0f\n\r_angular_rateB\x0f\n\r_accelerationB\x0b\n\t_magfieldB\x08\n\x06_eulerB\x12\n\x10_euler_error_deg\"4\n\nAltitudeIf\x12\x17\n\naltitude_m\x18\x01 \x01(\x01H\x00\x88\x01\x01\x42\r\n\x0b_altitude_m\"\x99\x01\n\tBatteryIf\x12\x16\n\tvoltage_V\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x16\n\tcurrent_A\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12$\n\x17state_of_charge_percent\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x0c\n\n_voltage_VB\x0c\n\n_current_AB\x1a\n\x18_state_of_charge_percent\"+\n\x07\x44\x65pthIf\x12\x14\n\x07\x64\x65pth_m\x18\x01 \x01(\x01H\x00\x88\x01\x01\x42\n\n\x08_depth_m\"\x1d\n\nEffectorIf\x12\x0f\n\x07\x63ommand\x18\x01 \x03(\x01\"\xf4\x05\n\x05InsIf\x12\x42\n\x0c\x61ngular_rate\x18\x01 \x01(\x0b\x32\'.magothy.protobuf.autopilot.AngularRateH\x00\x88\x01\x01\x12\x43\n\x0c\x61\x63\x63\x65leration\x18\x02 \x01(\x0b\x32(.magothy.protobuf.autopilot.AccelerationH\x01\x88\x01\x01\x12@\n\x08magfield\x18\x03 \x01(\x0b\x32).magothy.protobuf.autopilot.MagneticFieldH\x02\x88\x01\x01\x12\x35\n\x05\x65uler\x18\x04 \x01(\x0b\x32!.magothy.protobuf.autopilot.EulerH\x03\x88\x01\x01\x12?\n\x0f\x65uler_error_deg\x18\x08 \x01(\x0b\x32!.magothy.protobuf.autopilot.ErrorH\x04\x88\x01\x01\x12\x44\n\rbody_velocity\x18\x05 \x01(\x0b\x32(.magothy.protobuf.autopilot.BodyVelocityH\x05\x88\x01\x01\x12;\n\x08position\x18\x06 \x01(\x0b\x32$.magothy.protobuf.autopilot.PositionH\x06\x88\x01\x01\x12@\n\x10position_error_m\x18\t \x01(\x0b\x32!.magothy.protobuf.autopilot.ErrorH\x07\x88\x01\x01\x12L\n\x11inertial_velocity\x18\x07 \x01(\x0b\x32,.magothy.protobuf.autopilot.InertialVelocityH\x08\x88\x01\x01\x42\x0f\n\r_angular_rateB\x0f\n\r_accelerationB\x0b\n\t_magfieldB\x08\n\x06_eulerB\x12\n\x10_euler_error_degB\x10\n\x0e_body_velocityB\x0b\n\t_positionB\x13\n\x11_position_error_mB\x14\n\x12_inertial_velocity\"\xa3\x08\n\x05GpsIf\x12@\n\x08rmc_data\x18\x01 \x01(\x0b\x32).magothy.protobuf.autopilot.GpsIf.RmcDataH\x00\x88\x01\x01\x12@\n\x08gga_data\x18\x02 \x01(\x0b\x32).magothy.protobuf.autopilot.GpsIf.GgaDataH\x01\x88\x01\x01\x12@\n\x08gst_data\x18\x03 \x01(\x0b\x32).magothy.protobuf.autopilot.GpsIf.GstDataH\x02\x88\x01\x01\x1a\xc7\x01\n\x07RmcData\x12\x19\n\x0clatitude_deg\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x1a\n\rlongitude_deg\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x1c\n\x0fground_speed_kt\x18\x03 \x01(\x01H\x02\x88\x01\x01\x12\x1c\n\x0f\x63ourse_true_deg\x18\x04 \x01(\x01H\x03\x88\x01\x01\x42\x0f\n\r_latitude_degB\x10\n\x0e_longitude_degB\x12\n\x10_ground_speed_ktB\x12\n\x10_course_true_deg\x1a\xa0\x03\n\x07GgaData\x12\x19\n\x0clatitude_deg\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x1a\n\rlongitude_deg\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x17\n\naltitude_m\x18\x03 \x01(\x01H\x02\x88\x01\x01\x12\x1a\n\rnum_satellite\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12I\n\x0b\x66ix_quality\x18\x05 \x01(\x0e\x32\x34.magothy.protobuf.autopilot.GpsIf.GgaData.FixQuality\"\x99\x01\n\nFixQuality\x12\x0e\n\nFQ_INVALID\x10\x00\x12\n\n\x06\x46Q_GPS\x10\x01\x12\x0b\n\x07\x46Q_DGPS\x10\x02\x12\n\n\x06\x46Q_PPS\x10\x03\x12\x10\n\x0c\x46Q_RTK_FIXED\x10\x04\x12\x10\n\x0c\x46Q_RTK_FLOAT\x10\x05\x12\x10\n\x0c\x46Q_ESTIMATED\x10\x06\x12\r\n\tFQ_MANUAL\x10\x07\x12\x11\n\rFQ_SIMULATION\x10\x08\x42\x0f\n\r_latitude_degB\x10\n\x0e_longitude_degB\r\n\x0b_altitude_mB\x10\n\x0e_num_satellite\x1a\xbf\x01\n\x07GstData\x12!\n\x14std_latitude_error_m\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\"\n\x15std_longitude_error_m\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12!\n\x14std_altitude_error_m\x18\x03 \x01(\x01H\x02\x88\x01\x01\x42\x17\n\x15_std_latitude_error_mB\x18\n\x16_std_longitude_error_mB\x17\n\x15_std_altitude_error_mB\x0b\n\t_rmc_dataB\x0b\n\t_gga_dataB\x0b\n\t_gst_data\"\x8c\x05\n\nObstacleIf\x12\n\n\x02id\x18\x01 \x01(\t\x12?\n\x06\x63ircle\x18\x02 \x01(\x0b\x32-.magothy.protobuf.autopilot.ObstacleIf.CircleH\x00\x12\x41\n\x07polygon\x18\x03 \x01(\x0b\x32..magothy.protobuf.autopilot.ObstacleIf.PolygonH\x00\x12\x42\n\tzone_type\x18\x04 \x01(\x0e\x32/.magothy.protobuf.autopilot.ObstacleIf.ZoneType\x12\x15\n\ris_stationary\x18\x05 \x01(\x08\x12\x12\n\nlifespan_s\x18\x06 \x01(\x01\x12\x17\n\ncourse_deg\x18\x07 \x01(\x01H\x01\x88\x01\x01\x12\x16\n\tspeed_mps\x18\x08 \x01(\x01H\x02\x88\x01\x01\x12\x44\n\x11point_of_interest\x18\t \x01(\x0b\x32$.magothy.protobuf.autopilot.PositionH\x03\x88\x01\x01\x1aP\n\x06\x43ircle\x12\x34\n\x06origin\x18\x01 \x01(\x0b\x32$.magothy.protobuf.autopilot.Position\x12\x10\n\x08radius_m\x18\x02 \x01(\x01\x1a\x41\n\x07Polygon\x12\x36\n\x08vertices\x18\x01 \x03(\x0b\x32$.magothy.protobuf.autopilot.Position\"/\n\x08ZoneType\x12\x11\n\rZONE_KEEP_OUT\x10\x00\x12\x10\n\x0cZONE_KEEP_IN\x10\x01\x42\x0f\n\rObstacleOneOfB\r\n\x0b_course_degB\x0c\n\n_speed_mpsB\x14\n\x12_point_of_interest\"\x8f\x01\n\tObstacles\x12/\n\x0bttag_system\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0ettag_steady_ns\x18\x02 \x01(\x04\x12\x39\n\tobstacles\x18\x03 \x03(\x0b\x32&.magothy.protobuf.autopilot.ObstacleIf\"\xfd\x03\n\x04Path\x12/\n\x0bttag_system\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0ettag_steady_ns\x18\x02 \x01(\x04\x12\x32\n\x04path\x18\x03 \x03(\x0b\x32$.magothy.protobuf.autopilot.Position\x12\x39\n\tobstacles\x18\x04 \x03(\x0b\x32&.magothy.protobuf.autopilot.ObstacleIf\x12\x16\n\tspeed_mps\x18\x05 \x01(\x01H\x00\x88\x01\x01\x12\x38\n\x05start\x18\x06 \x01(\x0b\x32$.magothy.protobuf.autopilot.PositionH\x01\x88\x01\x01\x12<\n\tend_local\x18\x07 \x01(\x0b\x32$.magothy.protobuf.autopilot.PositionH\x02\x88\x01\x01\x12=\n\nend_global\x18\x08 \x01(\x0b\x32$.magothy.protobuf.autopilot.PositionH\x03\x88\x01\x01\x12\x39\n\x0bglobal_path\x18\t \x03(\x0b\x32$.magothy.protobuf.autopilot.PositionB\x0c\n\n_speed_mpsB\x08\n\x06_startB\x0c\n\n_end_localB\r\n\x0b_end_global\"\x84\x07\n\x0eVehicleStateIf\x12\x0f\n\x07ttag_ns\x18\x01 \x01(\x04\x12=\n\x0cvehicle_data\x18\x02 \x01(\x0b\x32\'.magothy.protobuf.autopilot.VehicleData\x12=\n\x04mode\x18\x03 \x01(\x0e\x32/.magothy.protobuf.autopilot.VehicleStateIf.Mode\x12K\n\x0chealth_items\x18\x04 \x03(\x0b\x32\x35.magothy.protobuf.autopilot.VehicleStateIf.HealthItem\x12U\n\x0e\x66\x61ult_response\x18\x05 \x01(\x0b\x32\x38.magothy.protobuf.autopilot.VehicleStateIf.FaultResponseH\x00\x88\x01\x01\x1ar\n\nHealthItem\x12\r\n\x05index\x18\x01 \x01(\r\x12\x0b\n\x03uid\x18\x02 \x01(\t\x12\x11\n\tsensor_id\x18\x03 \x01(\r\x12\x10\n\x08is_valid\x18\x04 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x05 \x01(\x08\x12\x12\n\nis_healthy\x18\x06 \x01(\x08\x1a\x7f\n\rFaultResponse\x12S\n\rresponse_type\x18\x01 \x01(\x0e\x32<.magothy.protobuf.autopilot.VehicleStateIf.FaultResponseType\x12\x19\n\x11health_item_index\x18\x02 \x01(\r\"\xa2\x01\n\x04Mode\x12\x0e\n\nVS_STANDBY\x10\x00\x12\r\n\tVS_MANUAL\x10\x01\x12\x16\n\x12VS_HEALTHY_MISSION\x10\x02\x12\x18\n\x14VS_UNHEALTHY_MISSION\x10\x03\x12\r\n\tVS_LOITER\x10\x04\x12\x17\n\x13VS_MISSION_PLANNING\x10\x05\x12!\n\x1dVS_UNHEALTHY_MISSION_PLANNING\x10\x06\"\x91\x01\n\x11\x46\x61ultResponseType\x12\r\n\tFR_IGNORE\x10\x00\x12\x0b\n\x07\x46R_HALT\x10\x01\x12\r\n\tFR_LOITER\x10\x02\x12\x0f\n\x0b\x46R_GO_RALLY\x10\x03\x12\x0f\n\x0b\x46R_GO_FIRST\x10\x04\x12\x0e\n\nFR_GO_LAST\x10\x05\x12\x10\n\x0c\x46R_GO_LAUNCH\x10\x06\x12\r\n\tFR_CUSTOM\x10\x07\x42\x11\n\x0f_fault_response\"\x93\x02\n\x15MavlinkMissionItemInt\x12\x15\n\rtarget_system\x18\x01 \x01(\r\x12\x18\n\x10target_component\x18\x02 \x01(\r\x12\x14\n\x0cmission_type\x18\x03 \x01(\r\x12\x0b\n\x03seq\x18\x04 \x01(\r\x12\x0f\n\x07\x63ommand\x18\x05 \x01(\r\x12\r\n\x05\x66rame\x18\x06 \x01(\r\x12\x0f\n\x07\x63urrent\x18\x07 \x01(\x08\x12\x14\n\x0c\x61utocontinue\x18\x08 \x01(\x08\x12\x0e\n\x06param1\x18\t \x01(\x02\x12\x0e\n\x06param2\x18\n \x01(\x02\x12\x0e\n\x06param3\x18\x0b \x01(\x02\x12\x0e\n\x06param4\x18\x0c \x01(\x02\x12\t\n\x01x\x18\r \x01(\x05\x12\t\n\x01y\x18\x0e \x01(\x05\x12\t\n\x01z\x18\x0f \x01(\x02\"\xea\x01\n\x0eMavlinkMission\x12H\n\rmission_items\x18\x01 \x03(\x0b\x32\x31.magothy.protobuf.autopilot.MavlinkMissionItemInt\x12\x46\n\x0b\x66\x65nce_items\x18\x02 \x03(\x0b\x32\x31.magothy.protobuf.autopilot.MavlinkMissionItemInt\x12\x46\n\x0brally_items\x18\x03 \x03(\x0b\x32\x31.magothy.protobuf.autopilot.MavlinkMissionItemIntb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'autopilot_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ERROR']._serialized_start=80
  _globals['_ERROR']._serialized_end=120
  _globals['_POSITION']._serialized_start=122
  _globals['_POSITION']._serialized_end=177
  _globals['_ANGULARRATE']._serialized_start=179
  _globals['_ANGULARRATE']._serialized_end=237
  _globals['_ACCELERATION']._serialized_start=239
  _globals['_ACCELERATION']._serialized_end=301
  _globals['_MAGNETICFIELD']._serialized_start=303
  _globals['_MAGNETICFIELD']._serialized_end=369
  _globals['_EULER']._serialized_start=371
  _globals['_EULER']._serialized_end=436
  _globals['_BODYVELOCITY']._serialized_start=438
  _globals['_BODYVELOCITY']._serialized_end=497
  _globals['_INERTIALVELOCITY']._serialized_start=499
  _globals['_INERTIALVELOCITY']._serialized_end=572
  _globals['_WATERCURRENT']._serialized_start=574
  _globals['_WATERCURRENT']._serialized_end=630
  _globals['_FUELGAUGE']._serialized_start=632
  _globals['_FUELGAUGE']._serialized_end=714
  _globals['_VEHICLEDATA']._serialized_start=717
  _globals['_VEHICLEDATA']._serialized_end=3706
  _globals['_VEHICLEDATA_DATASOURCE']._serialized_start=3268
  _globals['_VEHICLEDATA_DATASOURCE']._serialized_end=3447
  _globals['_AHRSIF']._serialized_start=3709
  _globals['_AHRSIF']._serialized_end=4117
  _globals['_ALTITUDEIF']._serialized_start=4119
  _globals['_ALTITUDEIF']._serialized_end=4171
  _globals['_BATTERYIF']._serialized_start=4174
  _globals['_BATTERYIF']._serialized_end=4327
  _globals['_DEPTHIF']._serialized_start=4329
  _globals['_DEPTHIF']._serialized_end=4372
  _globals['_EFFECTORIF']._serialized_start=4374
  _globals['_EFFECTORIF']._serialized_end=4403
  _globals['_INSIF']._serialized_start=4406
  _globals['_INSIF']._serialized_end=5162
  _globals['_GPSIF']._serialized_start=5165
  _globals['_GPSIF']._serialized_end=6224
  _globals['_GPSIF_RMCDATA']._serialized_start=5373
  _globals['_GPSIF_RMCDATA']._serialized_end=5572
  _globals['_GPSIF_GGADATA']._serialized_start=5575
  _globals['_GPSIF_GGADATA']._serialized_end=5991
  _globals['_GPSIF_GGADATA_FIXQUALITY']._serialized_start=5770
  _globals['_GPSIF_GGADATA_FIXQUALITY']._serialized_end=5923
  _globals['_GPSIF_GSTDATA']._serialized_start=5994
  _globals['_GPSIF_GSTDATA']._serialized_end=6185
  _globals['_OBSTACLEIF']._serialized_start=6227
  _globals['_OBSTACLEIF']._serialized_end=6879
  _globals['_OBSTACLEIF_CIRCLE']._serialized_start=6615
  _globals['_OBSTACLEIF_CIRCLE']._serialized_end=6695
  _globals['_OBSTACLEIF_POLYGON']._serialized_start=6697
  _globals['_OBSTACLEIF_POLYGON']._serialized_end=6762
  _globals['_OBSTACLEIF_ZONETYPE']._serialized_start=6764
  _globals['_OBSTACLEIF_ZONETYPE']._serialized_end=6811
  _globals['_OBSTACLES']._serialized_start=6882
  _globals['_OBSTACLES']._serialized_end=7025
  _globals['_PATH']._serialized_start=7028
  _globals['_PATH']._serialized_end=7537
  _globals['_VEHICLESTATEIF']._serialized_start=7540
  _globals['_VEHICLESTATEIF']._serialized_end=8440
  _globals['_VEHICLESTATEIF_HEALTHITEM']._serialized_start=7865
  _globals['_VEHICLESTATEIF_HEALTHITEM']._serialized_end=7979
  _globals['_VEHICLESTATEIF_FAULTRESPONSE']._serialized_start=7981
  _globals['_VEHICLESTATEIF_FAULTRESPONSE']._serialized_end=8108
  _globals['_VEHICLESTATEIF_MODE']._serialized_start=8111
  _globals['_VEHICLESTATEIF_MODE']._serialized_end=8273
  _globals['_VEHICLESTATEIF_FAULTRESPONSETYPE']._serialized_start=8276
  _globals['_VEHICLESTATEIF_FAULTRESPONSETYPE']._serialized_end=8421
  _globals['_MAVLINKMISSIONITEMINT']._serialized_start=8443
  _globals['_MAVLINKMISSIONITEMINT']._serialized_end=8718
  _globals['_MAVLINKMISSION']._serialized_start=8721
  _globals['_MAVLINKMISSION']._serialized_end=8955
# @@protoc_insertion_point(module_scope)
