# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vision.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cvision.proto\x12\x17magothy.protobuf.vision\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"]\n\x05\x43olor\x12\x0b\n\x03red\x18\x01 \x01(\x02\x12\r\n\x05green\x18\x02 \x01(\x02\x12\x0c\n\x04\x62lue\x18\x03 \x01(\x02\x12*\n\x05\x61lpha\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\"\xb5\x01\n\x0f\x46ramePrediction\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\r\n\x05width\x18\x03 \x01(\x02\x12\x0e\n\x06height\x18\x04 \x01(\x02\x12\x12\n\nconfidence\x18\x05 \x01(\x02\x12\x10\n\x08\x63lass_id\x18\x06 \x01(\x05\x12\x12\n\nclass_name\x18\x07 \x01(\t\x12\x33\n\x0b\x63lass_color\x18\x08 \x01(\x0b\x32\x1e.magothy.protobuf.vision.Color\"\xc5\x01\n\x05\x46rame\x12\x14\n\x0c\x66rame_number\x18\x01 \x01(\x04\x12/\n\x0bttag_system\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0ettag_steady_ns\x18\x03 \x01(\x04\x12\x1e\n\x16prediction_duration_ms\x18\x04 \x01(\r\x12=\n\x0bpredictions\x18\x05 \x03(\x0b\x32(.magothy.protobuf.vision.FramePrediction\"\xc3\x02\n\x0cOccupancyMap\x12/\n\x0bttag_system\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0ettag_steady_ns\x18\x02 \x01(\x04\x12\x38\n\x04type\x18\x03 \x01(\x0e\x32*.magothy.protobuf.vision.OccupancyMap.Type\x12\x0f\n\x07lat_deg\x18\x04 \x01(\x01\x12\x0f\n\x07lon_deg\x18\x05 \x01(\x01\x12\x0f\n\x07width_m\x18\x06 \x01(\x01\x12\x10\n\x08height_m\x18\x07 \x01(\x01\x12\x10\n\x08width_px\x18\x08 \x01(\r\x12\x11\n\theight_px\x18\t \x01(\r\x12\x0c\n\x04grid\x18\n \x01(\x0c\"8\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05\x45MPTY\x10\x01\x12\x0c\n\x08OCCUPIED\x10\x02\x12\n\n\x06MERGED\x10\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vision_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_COLOR']._serialized_start=106
  _globals['_COLOR']._serialized_end=199
  _globals['_FRAMEPREDICTION']._serialized_start=202
  _globals['_FRAMEPREDICTION']._serialized_end=383
  _globals['_FRAME']._serialized_start=386
  _globals['_FRAME']._serialized_end=583
  _globals['_OCCUPANCYMAP']._serialized_start=586
  _globals['_OCCUPANCYMAP']._serialized_end=909
  _globals['_OCCUPANCYMAP_TYPE']._serialized_start=853
  _globals['_OCCUPANCYMAP_TYPE']._serialized_end=909
# @@protoc_insertion_point(module_scope)
