# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: radar.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bradar.proto\x12\x16magothy.protobuf.radar\x1a\x1fgoogle/protobuf/timestamp.proto\"=\n\x04Pose\x12\x0f\n\x07lat_deg\x18\x01 \x01(\x01\x12\x0f\n\x07lon_deg\x18\x02 \x01(\x01\x12\x13\n\x0bheading_deg\x18\x03 \x01(\x02\"W\n\x06Spokes\x12\x11\n\tnum_spoke\x18\x01 \x01(\r\x12\x19\n\x11\x66irst_spoke_index\x18\x02 \x01(\r\x12\x0f\n\x07range_m\x18\x03 \x01(\x02\x12\x0e\n\x06spokes\x18\x04 \x03(\x0c\"\xc1\x02\n\x04Info\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0ettag_steady_ns\x18\t \x01(\x04\x12,\n\x05state\x18\x02 \x01(\x0e\x32\x1d.magothy.protobuf.radar.State\x12\x0c\n\x04gain\x18\x03 \x01(\x05\x12\x0c\n\x04rain\x18\x04 \x01(\x05\x12\x0b\n\x03sea\x18\x05 \x01(\x05\x12\r\n\x05range\x18\x06 \x01(\x05\x12\x12\n\nscan_speed\x18\x07 \x01(\x05\x12\x33\n\x06spokes\x18\x08 \x01(\x0b\x32\x1e.magothy.protobuf.radar.SpokesH\x00\x88\x01\x01\x12/\n\x04pose\x18\n \x01(\x0b\x32\x1c.magothy.protobuf.radar.PoseH\x01\x88\x01\x01\x42\t\n\x07_spokesB\x07\n\x05_pose\"N\n\x07\x43ommand\x12\x34\n\x07\x63ommand\x18\x01 \x01(\x0e\x32#.magothy.protobuf.radar.CommandType\x12\r\n\x05value\x18\x02 \x01(\x03*\xc1\x01\n\x05State\x12\r\n\tSTATE_OFF\x10\x00\x12\x11\n\rSTATE_STANDBY\x10\x01\x12\x14\n\x10STATE_WARMING_UP\x10\x02\x12\x14\n\x10STATE_TIMED_IDLE\x10\x03\x12\x12\n\x0eSTATE_STOPPING\x10\x04\x12\x17\n\x13STATE_SPINNING_DOWN\x10\x05\x12\x12\n\x0eSTATE_STARTING\x10\x06\x12\x15\n\x11STATE_SPINNING_UP\x10\x07\x12\x12\n\x0eSTATE_TRANSMIT\x10\x08*w\n\x0b\x43ommandType\x12\x10\n\x0c\x43OMMAND_NONE\x10\x00\x12\x13\n\x0f\x43OMMAND_TURN_ON\x10\x01\x12\x14\n\x10\x43OMMAND_TURN_OFF\x10\x02\x12\x15\n\x11\x43OMMAND_SET_RANGE\x10\x03\x12\x14\n\x10\x43OMMAND_SET_GAIN\x10\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'radar_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_STATE']._serialized_start=629
  _globals['_STATE']._serialized_end=822
  _globals['_COMMANDTYPE']._serialized_start=824
  _globals['_COMMANDTYPE']._serialized_end=943
  _globals['_POSE']._serialized_start=72
  _globals['_POSE']._serialized_end=133
  _globals['_SPOKES']._serialized_start=135
  _globals['_SPOKES']._serialized_end=222
  _globals['_INFO']._serialized_start=225
  _globals['_INFO']._serialized_end=546
  _globals['_COMMAND']._serialized_start=548
  _globals['_COMMAND']._serialized_end=626
# @@protoc_insertion_point(module_scope)
